@@ -139,7 +139,7 @@ class Line(metaclass=PoolMeta):
                 product_supplier = request.find_best_product_supplier(
                     self.product, self.shipping_date,
                     **self._get_purchase_request_product_supplier_pattern())
-                if product_supplier.drop_shipment:
+                if product_supplier and product_supplier.drop_shipment:
                     request.customer = (
                         self.sale.shipment_party or self.sale.party)
                     request.delivery_address = self.sale.shipment_address
